@@ -3,11 +3,10 @@ use warnings;
 
 use lib qw( ../../../../lib );
 
-=encoding utf8
-
 =head1 NAME
 
-Algorithm::Evolutionary::Fitness::Any - Façade for any function so that it can be used as fitness
+Algorithm::Evolutionary::Fitness::Any - Faade for any function to
+look like fitness
 
 =head1 SYNOPSIS
 
@@ -19,8 +18,9 @@ Algorithm::Evolutionary::Fitness::Any - Façade for any function so that it can
      return $values[0] * $values[1];
    }
 
-   my $any_eval = new Algorithm::Evolutionary::Fitness::Any \&squares;
+   my $any_eval = new Algorithm::Evolutionary::Fitness::Any \&squares
 
+   
 
 =head1 DESCRIPTION
 
@@ -37,7 +37,7 @@ use Carp;
 
 use base 'Algorithm::Evolutionary::Fitness::Base';
 
-our $VERSION =  '3.2';
+our $VERSION =   sprintf "%d.%03d", q$Revision: 2.1 $ =~ /(\d+)\.(\d+)/g; 
 
 =head2 new( $function )
 
@@ -55,8 +55,8 @@ sub new {
 
 =head2 apply( $individual )
 
-Applies the instantiated problem to a chromosome. It is actually a
-wrapper around C<_apply>.
+Applies the instantiated problem to a chromosome. Actually it is a
+wrapper around C<_apply>
 
 =cut
 
@@ -70,7 +70,7 @@ sub apply {
 =head2 _apply( $individual )
 
 This is the one that really does the stuff. It applies the defined
-function to each individual. Itis cached for efficiency.
+function to each individual 
 
 =cut
 
@@ -95,6 +95,11 @@ sub _apply {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2009/07/22 12:07:03 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Any.pm,v 2.1 2009/07/22 12:07:03 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 2.1 $
+
 =cut
 
 "What???";
