@@ -1,50 +1,47 @@
-package Algorithm::Evolutionary::Fitness::Trap; # -*- cperl -*-
-
-use strict; 
+use strict; # -*- cperl -*-
 use warnings;
-use Carp qw(croak);
-
-our $VERSION = '3.2';
-
-use lib qw(../../.. ../.. .. ../../../../lib);
-
-use base qw(Algorithm::Evolutionary::Fitness::String);
 
+use lib qw( ../../../../lib );
 
 =head1 NAME
 
-Algorithm::Evolutionary::Fitness::Trap - 'Trap' fitness function for evolutionary algorithms
+Algorithm::Evolutionary::Fitness::Trap - Error Correcting codes problem generator
 
 =head1 SYNOPSIS
 
     my $number_of_bits = 5;
-    my $a = $number_of_bits -1; # Usual default values follow
+    my $a = $number_of_bits -1;
     my $b = $number_of_bits;
     my $z = $number_of_bits -1;
     my $trap = Algorithm::Evolutionary::Fitness::Trap->new( $number_of_bits, $a, $b, $z );
 
-# Equivalent to
-
-    $trap = Algorithm::Evolutionary::Fitness::Trap->new( $number_of_bits );
-
-    my $chromosome = "10101111110000";
-    my $fitness = $trap->apply( $chromosome );
-
 =head1 DESCRIPTION
 
-Trap functions act as "yucky" or deceptive for evolutionary algorithms;
-they "trap" population into going to easier, but local, optima.
+Trap function act as "yucky" or deceptive for evolutionary algorithms;
+they "trap" population into going to easier, but local optima.
 
 =head1 METHODS
 
-
-=head2 new( $number_of_bits, [$a = $number_of_bits -1, $b = $number_of_bits, $z=$number_of_bits-1])
-
-Creates a new instance of the problem, with the said number of bits
-and traps. Uses default values from C<$number_of_bits> if needed
-
 =cut
 
+package Algorithm::Evolutionary::Fitness::Trap;
+
+our ($VERSION) = ( '$Revision: 1.2 $ ' =~ / (\d+\.\d+)/ ) ;
+
+use String::Random;
+use Carp qw(croak);
+
+use lib qw(../../.. ../.. ..);
+
+use base qw(Algorithm::Evolutionary::Fitness::String);
+use Algorithm::Evolutionary::Utils qw(hamming);
+
+=head2 new
+
+    Creates a new instance of the problem, with the said number of bits and peaks
+
+=cut 
+
 sub new {
   my $class = shift;
   my $number_of_bits = shift || croak "Need non-null number of bits\n";
@@ -76,10 +73,9 @@ sub _really_apply {
   return $self->trap( @_ );
 }
 
-=head2 trap( $string )
+=head2 trap
 
-Computes the value of the trap function on the C<$string>. Optimum is
-number_of_blocs * $b (by default, $b = $l or number of ones) 
+Computes the value of the trap function
 
 =cut
 
@@ -110,6 +106,7 @@ sub trap {
       $total += $cache->{$key};
     }
     $cache->{$string} = $total;
+	
     return $cache->{$string};
 
 }
@@ -119,7 +116,12 @@ sub trap {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2009/04/24 18:09:21 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Trap.pm,v 1.2 2009/04/24 18:09:21 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 1.2 $
+  $Name $
+
 =cut
 
-"Gotcha trapped!";
-
+"What???";
