@@ -37,6 +37,11 @@ use warnings;
     print $indi3->asXML() #Prints it as XML. See 
     print $indi3->as_yaml() #Change of convention, I know...
 
+    my $gene_size = 5;
+    my $min = -1;
+    my $range = 2;
+    my @decoded_vector = $indi3->decode( $gene_size, $min, $range);
+
 =head1 Base Class
 
 L<Algorithm::Evolutionary::Individual::String|Algorithm::Evolutionary::Individual::String>
@@ -48,15 +53,17 @@ Bitstring Individual for a Genetic Algorithm. Used, for instance, in a canonical
 =cut
 
 package Algorithm::Evolutionary::Individual::BitString;
+
 use Carp;
 
-our ($VERSION) =  ( '$Revision: 1.5 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) =  ( '$Revision: 2.3 $ ' =~ /(\d+\.\d+)/ );
 
 use base 'Algorithm::Evolutionary::Individual::String';
 
 use constant MY_OPERATORS => (Algorithm::Evolutionary::Individual::String::MY_OPERATORS, 
 			      qw(Algorithm::Evolutionary::Op::BitFlip Algorithm::Evolutionary::Op::Mutation )); 
- 
+
+use Algorithm::Evolutionary::Utils qw(decode_string); 
 
 =head1 METHODS
 
@@ -89,16 +96,29 @@ sub set {
   $self->SUPER::set( $hash );
 }
 
+=head2 decode( $gene_size, $min, $range )
+
+Decodes to a vector, each one of whose components ranges between $min
+and $max. Returns that vector
+
+=cut
+
+sub decode {
+  my $self = shift;
+  my ( $gene_size, $min, $range ) = @_;
+  my $chromosome = $self->{'_str'};
+  return decode_chromosome( $chromosome, $gene_size, $min, $range );
+}
 
 =head2 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/07/25 11:26:17 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/BitString.pm,v 1.5 2008/07/25 11:26:17 jmerelo Exp $ 
+  CVS Info: $Date: 2009/07/22 12:07:03 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/BitString.pm,v 2.3 2009/07/22 12:07:03 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.5 $
+  $Revision: 2.3 $
   $Name $
 
 =cut
